@@ -152,6 +152,8 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from ._jsii import *
 
 import aws_cdk.aws_cloudwatch
@@ -171,12 +173,12 @@ class EventbridgeToStepfunctions(
         scope: aws_cdk.core.Construct,
         id: builtins.str,
         *,
-        event_rule_props: aws_cdk.aws_events.RuleProps,
-        state_machine_props: aws_cdk.aws_stepfunctions.StateMachineProps,
+        event_rule_props: typing.Union[aws_cdk.aws_events.RuleProps, typing.Dict[str, typing.Any]],
+        state_machine_props: typing.Union[aws_cdk.aws_stepfunctions.StateMachineProps, typing.Dict[str, typing.Any]],
         create_cloud_watch_alarms: typing.Optional[builtins.bool] = None,
-        event_bus_props: typing.Optional[aws_cdk.aws_events.EventBusProps] = None,
+        event_bus_props: typing.Optional[typing.Union[aws_cdk.aws_events.EventBusProps, typing.Dict[str, typing.Any]]] = None,
         existing_event_bus_interface: typing.Optional[aws_cdk.aws_events.IEventBus] = None,
-        log_group_props: typing.Optional[aws_cdk.aws_logs.LogGroupProps] = None,
+        log_group_props: typing.Optional[typing.Union[aws_cdk.aws_logs.LogGroupProps, typing.Dict[str, typing.Any]]] = None,
     ) -> None:
         '''
         :param scope: - represents the scope for all the resources.
@@ -191,6 +193,10 @@ class EventbridgeToStepfunctions(
         :access: public
         :summary: Constructs a new instance of the EventbridgeToStepfunctions class.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(EventbridgeToStepfunctions.__init__)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = EventbridgeToStepfunctionsProps(
             event_rule_props=event_rule_props,
             state_machine_props=state_machine_props,
@@ -246,12 +252,12 @@ class EventbridgeToStepfunctionsProps:
     def __init__(
         self,
         *,
-        event_rule_props: aws_cdk.aws_events.RuleProps,
-        state_machine_props: aws_cdk.aws_stepfunctions.StateMachineProps,
+        event_rule_props: typing.Union[aws_cdk.aws_events.RuleProps, typing.Dict[str, typing.Any]],
+        state_machine_props: typing.Union[aws_cdk.aws_stepfunctions.StateMachineProps, typing.Dict[str, typing.Any]],
         create_cloud_watch_alarms: typing.Optional[builtins.bool] = None,
-        event_bus_props: typing.Optional[aws_cdk.aws_events.EventBusProps] = None,
+        event_bus_props: typing.Optional[typing.Union[aws_cdk.aws_events.EventBusProps, typing.Dict[str, typing.Any]]] = None,
         existing_event_bus_interface: typing.Optional[aws_cdk.aws_events.IEventBus] = None,
-        log_group_props: typing.Optional[aws_cdk.aws_logs.LogGroupProps] = None,
+        log_group_props: typing.Optional[typing.Union[aws_cdk.aws_logs.LogGroupProps, typing.Dict[str, typing.Any]]] = None,
     ) -> None:
         '''
         :param event_rule_props: User provided eventRuleProps to override the defaults. Default: - None
@@ -271,6 +277,14 @@ class EventbridgeToStepfunctionsProps:
             event_bus_props = aws_cdk.aws_events.EventBusProps(**event_bus_props)
         if isinstance(log_group_props, dict):
             log_group_props = aws_cdk.aws_logs.LogGroupProps(**log_group_props)
+        if __debug__:
+            type_hints = typing.get_type_hints(EventbridgeToStepfunctionsProps.__init__)
+            check_type(argname="argument event_rule_props", value=event_rule_props, expected_type=type_hints["event_rule_props"])
+            check_type(argname="argument state_machine_props", value=state_machine_props, expected_type=type_hints["state_machine_props"])
+            check_type(argname="argument create_cloud_watch_alarms", value=create_cloud_watch_alarms, expected_type=type_hints["create_cloud_watch_alarms"])
+            check_type(argname="argument event_bus_props", value=event_bus_props, expected_type=type_hints["event_bus_props"])
+            check_type(argname="argument existing_event_bus_interface", value=existing_event_bus_interface, expected_type=type_hints["existing_event_bus_interface"])
+            check_type(argname="argument log_group_props", value=log_group_props, expected_type=type_hints["log_group_props"])
         self._values: typing.Dict[str, typing.Any] = {
             "event_rule_props": event_rule_props,
             "state_machine_props": state_machine_props,
